'\" te
.\" Copyright (c) 2007, Sun Microsystems, Inc. All Rights Reserved.
.\" The contents of this file are subject to the terms of the Common Development and Distribution License (the "License").  You may not use this file except in compliance with the License.
.\" You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE or http://www.opensolaris.org/os/licensing.  See the License for the specific language governing permissions and limitations under the License.
.\" When distributing Covered Code, include this CDDL HEADER in each file and include the License file at usr/src/OPENSOLARIS.LICENSE.  If applicable, add the following below this CDDL HEADER, with the fields enclosed by brackets "[]" replaced with your own identifying information: Portions Copyright [yyyy] [name of copyright owner]
.TH GETISAX 2 "Nov 7, 2007"
.SH NAME
getisax \- extract valid instruction set extensions
.SH SYNOPSIS
.LP
.nf
#include <sys/auxv.h>

\fBuint_t\fR \fBgetisax\fR(\fBuint32_t *\fR\fIarray\fR, \fBuint_t\fR \fIn\fR);
.fi

.SH DESCRIPTION
.LP
The \fBgetisax()\fR function sets the vector \fIarray\fR of \fIn\fR 32-bit
integers to contain the bits from the \fBAV\fR_\fIxxx\fR_\fIyyy\fR namespace of
the given instruction set architecture.
.sp
.LP
Values for \fBAV\fR_\fIxxx\fR_\fIyyy\fR for SPARC and SPARCV9, and their
associated descriptions, can be found in \fB<sys/auxv_SPARC.h>\fR.
.sp
.LP
Values for \fBAV\fR_\fIxxx\fR_\fIyyy\fR for i386 and AMD64, and their
associated descriptions, can be found in \fB<sys/auxv_386.h>\fR.
.SH RETURN VALUES
.LP
The \fBgetisax()\fR function returns the number of array elements that contain
non-zero values.
.SH EXAMPLES
.LP
\fBExample 1 \fRUse \fBgetisax()\fR to determine if the SSE2 instruction set is
present.
.sp
.LP
In the following example, if the message is written, the SSE2 instruction set
is present and fully supported by the operating system.

.sp
.in +2
.nf
uint_t ui;

(void) getisax(&ui, 1);

if (ui & AV_386_SSE2)
        printf("SSE2 instruction set extension is present.\en");
.fi
.in -2

.SH ATTRIBUTES
.LP
See \fBattributes\fR(5) for descriptions of the following attributes:
.sp

.sp
.TS
box;
c | c
l | l .
ATTRIBUTE TYPE	ATTRIBUTE VALUE
_
Interface Stability	Committed
_
MT-Level	Safe
.TE

.SH SEE ALSO
.LP
\fBisainfo\fR(1), \fBld\fR(1), \fBpargs\fR(1), \fBattributes\fR(5)
.sp
.LP
\fILinker and Libraries Guide\fR
.sp
.LP
\fISPARC Assembly Language Reference Manual\fR
.sp
.LP
\fIx86 Assembly Language Reference Manual\fR
